<template>
  <div class="app-container">
    <div class="search_form">
      <div>
        <span class="search_title">供应商名称：</span>
        <el-input v-model="searchForm.searchText" style="width: 240px" placeholder="输入供应商名称搜索"
          @change="handleQuery" clearable :prefix-icon="Search" />
        <el-button type="primary" @click="handleQuery" style="margin-left: 10px">搜索</el-button>
      </div>
    </div>
    <div class="table_list">
      <PIMTable :column="tableColumn" :tableData="tableData" :page="page" :isSelection="true"
        :handleSelectionChange="handleSelectionChange" :tableLoading="tableLoading" @pagination="pagination"
        :total="total"></PIMTable>
    </div>
  </div>
</template>

<script setup>
import { ref } from 'vue'
import { Search } from "@element-plus/icons-vue";
import {
  paymentHistoryList
} from "@/api/procurementManagement/paymentEntry.js";
const { proxy } = getCurrentInstance()
const tableColumn = ref([
  {
    label: '付款日期',
    prop: 'paymentDate',
  },
  {
    label: '供应商名称',
    prop: 'supplierName',
  },
  {
    label: '付款金额',
    prop: 'currentPaymentAmount',
  },
  {
    label: '付款方式',
    prop: 'paymentMethod'
  },
  {
    label: '登记人',
    prop: 'registrant'
  },
  {
    label: '登记日期',
    prop: 'registrationtDate'
  }
])
const tableData = ref([])
const selectedRows = ref([])
const tableLoading = ref(false)
const page = reactive({
  current: 1,
  size: 10,
})
const total = ref(0)
const data = reactive({
  searchForm: {
    searchText: '',
  },
})
const { searchForm } = toRefs(data)

// 查询列表
/** 搜索按钮操作 */
const handleQuery = () => {
  page.current = 1
  getList()
}
const pagination = ({ current, limit }) => {
  page.current = current;
  page.size = limit;
  getList()
}
const getList = () => {
  tableLoading.value = true
  paymentHistoryList({ ...searchForm.value, ...page }).then(res => {
    tableLoading.value = false
    tableData.value = res.rows
    total.value = res.total
  })
}
// 表格选择数据
const handleSelectionChange = (selection) => {
  selectedRows.value = selection
}
getList()
</script>

<style scoped lang="scss"></style>
